@@ -2,8 +2,11 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -44,12 +47,12 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.4.0"
+#define SUNDIALS_VERSION "7.5.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 4
+#define SUNDIALS_VERSION_MINOR 5
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
-#define SUNDIALS_GIT_VERSION "v7.4.0"
+#define SUNDIALS_GIT_VERSION "v7.5.0"
 
 
 /* ------------------------------------------------------------------
@@ -124,10 +127,10 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20250823090951"
-#define SUN_JOB_START_TIME "20250823090951"
+#define SUN_JOB_ID "20251028015941"
+#define SUN_JOB_START_TIME "20251028015941"
 
-#define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
+#define SUN_TPL_LIST "MPI;OPENMP;KLU;BLAS_LAPACK;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
 
 #define SUNDIALS_SPACK_VERSION ""
@@ -166,7 +169,7 @@
 #define SUN_KOKKOS_KERNELS_VERSION ""
 
 /* LAPACK */
-/* #undef SUNDIALS_BLAS_LAPACK_ENABLED */
+#define SUNDIALS_BLAS_LAPACK_ENABLED
 #define SUN_LAPACK_VERSION ""
 
 /* MAGMA */
@@ -302,6 +305,8 @@
 #define SUNDIALS_SUNLINSOL_SPGMR 1
 #define SUNDIALS_SUNLINSOL_SPTFQMR 1
 #define SUNDIALS_SUNLINSOL_KLU 1
+#define SUNDIALS_SUNLINSOL_LAPACKBAND 1
+#define SUNDIALS_SUNLINSOL_LAPACKDENSE 1
 #define SUNDIALS_SUNNONLINSOL_NEWTON 1
 #define SUNDIALS_SUNNONLINSOL_FIXEDPOINT 1
 
